@@ -5,6 +5,7 @@
 #include <history.h>
 #include <mutex.h>
 #include <regexmanager.h>
+#include <view.h>
 
 namespace newsbeuter {
 
@@ -17,9 +18,16 @@ class itemlist_formaction : public formaction {
 		virtual void prepare();
 		virtual void init();
 
+		virtual void set_redraw(bool b) {
+			formaction::set_redraw(b);
+			apply_filter = !(v->get_cfg()->get_configvalue_as_bool("show-read-articles"));
+			update_visible_items = true;
+		}
+
 		void set_feed(std::tr1::shared_ptr<rss_feed> fd);
 
 		virtual std::string id() const { return "articlelist"; }
+		virtual std::string title();
 
 		inline std::tr1::shared_ptr<rss_feed> get_feed() { return feed; }
 		inline void set_pos(unsigned int p) { pos = p; }
@@ -28,6 +36,7 @@ class itemlist_formaction : public formaction {
 
 		bool jump_to_next_unread_item(bool start_with_first);
 		bool jump_to_previous_unread_item(bool start_with_last);
+		bool jump_to_random_unread_item();
 
 		virtual void handle_cmdline(const std::string& cmd);
 
@@ -38,6 +47,7 @@ class itemlist_formaction : public formaction {
 		virtual void finished_qna(operation op);
 
 		inline void set_show_searchresult(bool b) { show_searchresult = b; }
+		inline void set_searchphrase(const std::string& s) { searchphrase = s; }
 
 		virtual void recalculate_form();
 
@@ -71,6 +81,7 @@ class itemlist_formaction : public formaction {
 		std::vector<itemptr_pos_pair> visible_items;
 		bool update_visible_items;
 		bool show_searchresult;
+		std::string searchphrase;
 
 		history filterhistory;
 
@@ -84,6 +95,8 @@ class itemlist_formaction : public formaction {
 		regexmanager * rxman;
 
 		unsigned int old_width;
+		int old_itempos;
+		std::string old_sort_order;
 };
 
 }
