@@ -89,6 +89,7 @@ void pb_view::run(bool auto_download) {
 			case OP_PB_TOGGLE_DLALL:
 				auto_download = !auto_download;
 				break;
+			case OP_HARDQUIT:
 			case OP_QUIT:
 				if (ctrl->downloads_in_progress() > 0) {
 					dllist_form.set("msg", _("Error: can't quit: download(s) in progress."));
@@ -120,7 +121,8 @@ void pb_view::run(bool auto_download) {
 					int idx = -1;
 					os >> idx;
 					if (idx != -1) {
-						if (ctrl->downloads()[idx].status() == DL_FINISHED) {
+						dlstatus_t status = ctrl->downloads()[idx].status();
+						if (status == DL_FINISHED || status == DL_PLAYED) {
 							ctrl->play_file(ctrl->downloads()[idx].filename());
 							ctrl->downloads()[idx].set_status(DL_PLAYED);
 						} else {
@@ -232,6 +234,7 @@ void pb_view::run_help() {
 		operation op = keys->get_operation(event, "help");
 
 		switch (op) {
+			case OP_HARDQUIT:
 			case OP_QUIT:
 				quit = true;
 				break;
