@@ -469,8 +469,9 @@ std::wstring utils::str2wstr(const std::string& str) {
 }
 
 std::string utils::wstr2str(const std::wstring& wstr) {
-	const char * codeset = nl_langinfo(CODESET);
-	struct stfl_ipool * ipool = stfl_ipool_create(codeset);
+	std::string codeset = nl_langinfo(CODESET);
+	codeset.append("//TRANSLIT");
+	struct stfl_ipool * ipool = stfl_ipool_create(codeset.c_str());
 	std::string result = stfl_ipool_fromwc(ipool, wstr.c_str());
 	stfl_ipool_destroy(ipool);
 	return result;
@@ -623,6 +624,27 @@ size_t utils::strwidth_stfl(const std::string& str) {
 	return strwidth(str) - reduce_count;
 }
 
+size_t utils::wcswidth_stfl(const std::wstring& str, size_t size) {
+	size_t reduce_count = 0;
+	size_t len = std::min(str.length(), size);
+	if (len > 1) {
+		for (size_t idx=0;idx<len-1;++idx) {
+			if (str[idx] == L'<' && str[idx+1] != L'>') {
+				reduce_count += 3;
+				idx += 3;
+			}
+		}
+	}
+
+	int width = wcswidth(str.c_str(), size);
+	if (width < 0) {
+		LOG(LOG_ERROR, "oh, oh, wcswidth just failed"); // : %ls", str.c_str());
+		return str.length() - reduce_count;
+	}
+
+	return width - reduce_count;
+}
+
 std::string utils::join(const std::vector<std::string>& strings, const std::string& separator) {
 	std::string result;
 
@@ -747,8 +769,10 @@ void utils::set_common_curl_options(CURL * handle, configcontainer * cfg) {
 
 	if (proxy != "")
 		curl_easy_setopt(handle, CURLOPT_PROXY, proxy.c_str());
-	if (proxyauth != "")
+	if (proxyauth != "") {
+		curl_easy_setopt(handle, CURLOPT_PROXYAUTH, CURLAUTH_ANY);
 		curl_easy_setopt(handle, CURLOPT_PROXYUSERPWD, proxyauth.c_str());
+	}
 	if (proxytype != "") {
 		LOG(LOG_DEBUG, "utils::set_common_curl_options: proxytype = %s", proxytype.c_str());
 		curl_easy_setopt(handle, CURLOPT_PROXYTYPE, get_proxy_type(proxytype));
@@ -796,8 +820,10 @@ curl_proxytype utils::get_proxy_type(const std::string& type) {
 		return CURLPROXY_SOCKS4;
 	if (type == "socks5")
 		return CURLPROXY_SOCKS5;
+#ifdef CURLPROXY_SOCKS4A
 	if (type == "socks4a")
 		return CURLPROXY_SOCKS4A;
+#endif
 
 	if (type != "") {
 		LOG(LOG_USERERROR, "you configured an invalid proxy type: %s", type.c_str());
